* `message` - make a plan, set a goal, record your thoughts, or ask for more input from the user. Arguments:
  * `content` - the thought to record
  * `wait_for_response` - set to `true` to wait for the user to respond before proceeding
